==> nhttpd-0.0.3.tar.gz: nhttpd-0.0.3/include/header.h <==
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <getopt.h>
#include <grp.h>
#include <libxml/globals.h>
#include <libgen.h>
#include <math.h>
#include <netinet/in.h>
#include <pthread.h>
#include <pwd.h>
#include <signal.h>
#include <string.h>
#include <sys/poll.h>
#include <sys/socket.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <time.h>
#include <unistd.h>
#include <netdb.h>
#include <arpa/inet.h>

#if !defined(__APPLE__)
#include <sys/sendfile.h>
#endif

#include "common.h"
#include "config.h"
#include "libhttpd.h"
#include "log.h"

/* main.c */
int throw_thread_pool( int accept_fd );


/* util.c */
int send_response( int listen_fd, char *buf, int buf_len );
int sendfile_response( int sockfd, int realfd, size_t readfd_len );

void set_pollfd( struct pollfd *pollfd, int fd, short events );
int open_real_file( char *filename, struct stat *filestat );
size_t write_file( char *filename, char *buf, size_t buf_len );


/* common.c */
attr_server *sock_init( sock_addr *sa, int port, int listen_backlog );
int initialize_socket( sock_addr *sa, int listen_backlog );

/* mime.c */
int set_mime( struct mime_t **mimes, int *mimes_len );
char *mime_type( struct http_request_header_t *header );


/* thread.c */
void *proc(void *data);
int get_vhost_filefd( struct http_request_header_t *header, struct stat *filestat, struct vhost_t *vhost );
int get_read_filefd( struct http_request_header_t *header, char *document_root, struct stat *filestat );


/* libxml.c */
xmlNode *xml_find_next_by_tag( xmlNode *start, char *tag_name );
xmlNode *xml_find_child_by_tag( xmlNode *parent, char *tag_name );
xmlNode *xml_find_doc_child_by_tag( xmlDocPtr parent, char *tag_name );
int xml_get_config_int_value( xmlNode *parent, char *tag_name, int default_value );
char *xml_get_config_char_value( xmlNode *parent, char *tag_name, char *default_value );
unsigned short xml_get_config_boolean_value( xmlNode *parent, char *tag_name, unsigned short default_value );
xmlChar *xml_get_attr_to_char( xmlNode *node, xmlChar *attr_name );
int xml_get_attr_to_int( xmlNode node, xmlChar *attr_name, int def_value );
double xml_get_attr_to_double( xmlNode node, xmlChar *attr_name, double def_value );

==> nhttpd-0.1.1.tar.gz: nhttpd-0.1.1/include/header.h <==
#define	SERVER_NAME	"nhttpd-alpha"
#define	SERVER_VERSION	"0.1.0"


#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <getopt.h>
#include <grp.h>
#include <libxml/globals.h>
#include <libgen.h>
#include <math.h>
#include <netinet/in.h>
#include <pthread.h>
#include <pwd.h>
#include <signal.h>
#include <string.h>
#include <sys/poll.h>
#include <sys/socket.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <time.h>
#include <unistd.h>
#include <netdb.h>
#include <arpa/inet.h>

#if !defined(__APPLE__)
#include <sys/sendfile.h>
#endif

#include "common.h"
#include "config.h"
#include "libhttpd.h"
#include "log.h"

/* main.c */
int throw_thread_pool( int accept_fd, struct sockaddr_in *addr );


/* util.c */
int send_response( int listen_fd, char *buf, int buf_len );
int sendfile_response( int sockfd, int realfd, size_t readfd_len );

void set_pollfd( struct pollfd *pollfd, int fd, short events );
int open_real_file( char *filename, struct stat *filestat );
size_t write_file( char *filename, char *buf, size_t buf_len );


/* common.c */
attr_server *sock_init( sock_addr *sa, int port, int listen_backlog );
int initialize_socket( sock_addr *sa, int listen_backlog );

/* mime.c */
int set_mime( struct mime_t **mimes, int *mimes_len );
char *mime_type( struct http_request_header_t *header );


/* thread.c */
void *proc(void *data);
int get_vhost_filefd( struct http_request_header_t *header, struct stat *filestat, struct vhost_t **vhost );
int get_read_filefd( struct http_request_header_t *header, char *document_root, struct stat *filestat );


/* libxml.c */
xmlNode *xml_find_next_by_tag( xmlNode *start, char *tag_name );
xmlNode *xml_find_child_by_tag( xmlNode *parent, char *tag_name );
xmlNode *xml_find_doc_child_by_tag( xmlDocPtr parent, char *tag_name );
int xml_get_config_int_value( xmlNode *parent, char *tag_name, int default_value );
char *xml_get_config_char_value( xmlNode *parent, char *tag_name, char *default_value );
unsigned short xml_get_config_boolean_value( xmlNode *parent, char *tag_name, unsigned short default_value );
xmlChar *xml_get_attr_to_char( xmlNode *node, xmlChar *attr_name );
int xml_get_attr_to_int( xmlNode node, xmlChar *attr_name, int def_value );
double xml_get_attr_to_double( xmlNode node, xmlChar *attr_name, double def_value );
